Module api_types
hocuspocus_
rs_
ws
0.1.0
Module api_
types
Module Items
Structs
Enums
Functions
In crate hocuspocus_
rs_
ws
hocuspocus_rs_ws
Module
api_
types
Structs

Auth
DocRequest
Client
Token
DocCreation
Request
NewDoc
Response
Enums

Authorization
Functions

validate_
doc_
name
Validate that the document name contains only alphanumeric characters, dashes, and underscores. This is the same alphabet used by nanoid when we generate a document name.